@@ -597,11 +597,11 @@ PYTHONS = {
     "3.10": "3.10.19",
     "3.11": "3.11.14",
     "3.12": "3.12.12",
-    "3.13": "3.13.8",
+    "3.13": "3.13.9",
     "3.13t": "3.13t-dev",
     "3.14": "3.14.0",
     "3.14t": "3.14t-dev",
-    "3.15": "3.15-dev",
+    "3.15": "3.15.0a1",
     "3.15t": "3.15t-dev",
     "pypy3.10": "pypy3.10-7.3.19",
     "pypy3.11": "pypy3.11-7.3.20",
